@@ -3,7 +3,7 @@ package Pod::ProjectDocs;
 use strict;
 use warnings;
 
-our $VERSION = '0.48_001'; # TRIAL VERSION
+our $VERSION = '0.48_002'; # TRIAL VERSION
 
 use base qw/Class::Accessor::Fast/;
 
@@ -266,7 +266,7 @@ without creating a custom perl script.
 
 =head1 SEE ALSO
 
-L<Pod::Parser>
+L<Pod::Simple::XHTML>
 
 =head1 AUTHORS
 
@@ -281,6 +281,7 @@ L<Pod::Parser>
 =head1 COPYRIGHT AND LICENSE
 
 Copyright(C) 2005 by Lyo Kato
+Copyright(C) 2017 by Martin Gruner
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.5 or,
