@@ -3,7 +3,7 @@ package Pod::ProjectDocs::IndexPage;
 use strict;
 use warnings;
 
-our $VERSION = '0.48_001'; # TRIAL VERSION
+our $VERSION = '0.48_002'; # TRIAL VERSION
 
 use base qw/Pod::ProjectDocs::File/;
 use Pod::ProjectDocs::Template;
@@ -117,6 +117,6 @@ function get_record_html (record, name, i) {
 
 <div id="list"></div>
 
-<div class="footer">generated by <a href="http://search.cpan.org/perldoc?Pod%3A%3AProjectDocs">Pod::ProjectDocs</a></div>
+<div class="footer">generated by <a href="http://metacpan.org/module/Pod::ProjectDocs">Pod::ProjectDocs</a></div>
 </body>
 </html>
